0.0.4 (2021-04-14)
------------------

### :hammer_and_wrench: Fixes

- Fixed entry point for `minimize` cli command


0.0.3 (2021-04-14)
------------------

### :sparkles: Added

- Added `minimize` cli command


0.0.1 (2021-04-13)
------------------

### :notebook: Notes

- Initial release of minimize
